package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppletOrderItemDate;

/**
 * 订单信息表Service接口
 *
 * @author daixiande
 */
public interface IAppletOrderItemDateService {
    /**
     * 查询订单信息表
     *
     * @param id 订单信息表主键
     * @return 订单信息表
     */
    AppletOrderItemDate selectAppletOrderItemDateById(Long id);

    /**
     * 查询订单信息表列表
     *
     * @param appletOrderItemDate 订单信息表
     * @return 订单信息表集合
     */
    List<AppletOrderItemDate> selectAppletOrderItemDateList(AppletOrderItemDate appletOrderItemDate);

    /**
     * 新增订单信息表
     *
     * @param appletOrderItemDate 订单信息表
     * @return 结果
     */
    int insertAppletOrderItemDate(AppletOrderItemDate appletOrderItemDate);

    /**
     * 修改订单信息表
     *
     * @param appletOrderItemDate 订单信息表
     * @return 结果
     */
    int updateAppletOrderItemDate(AppletOrderItemDate appletOrderItemDate);

    /**
     * 批量删除订单信息表
     *
     * @param ids 需要删除的订单信息表主键集合
     * @return 结果
     */
    int deleteAppletOrderItemDateByIds(Long[] ids);

    /**
     * 删除订单信息表信息
     *
     * @param id 订单信息表主键
     * @return 结果
     */
    int deleteAppletOrderItemDateById(Long id);
}
